Coverage for test_asg.py: 0%

# Coverage for test_asg.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | # -*- coding: utf-8 -*- import pytest from jungle import cli @pytest.mark.parametrize('asg_name', [ ('*'), ('asg-*'), ('asg-2'), ('dummy-asg'), ]) def test_asg_ls(runner, asg, asg_name): """jungle asg ls test""" result = runner.invoke(cli.cli, ['asg', 'ls', asg_name]) assert result.exit_code == 0